<?php
class FNMM_Backend {
    public function __construct() {
        // Add filter for plugin action links
        add_filter('plugin_action_links_fly-nav-mobile/fly-nav-mobile.php', array($this, 'add_plugin_action_links'));
    }

    // Add settings link to plugin listing
    public function add_plugin_action_links($links) {
        $settings_link = '<a href="' . admin_url('admin.php?page=fly-nav-mobile') . '">' . esc_html__('Settings', 'fly-nav-mobile') . '</a>';
        array_unshift($links, $settings_link);
        return $links;
    }

    // This function adds the plugin's settings page to the WordPress admin menu
    public function add_settings_page() {
        add_menu_page(
            esc_html__('Fly Nav Mobile', 'fly-nav-mobile'),
            esc_html__('Fly Menu', 'fly-nav-mobile'),
            'manage_options',
            'fly-nav-mobile',
            array($this, 'display_settings_page'),
            'dashicons-menu',
            80
        );
    }

    // This function creates the HTML for the settings page
    public function display_settings_page() {
        // Check if the user has permission to access this page
        if (!current_user_can('manage_options')) {
            return;
        }
        ?>
        <div class="wrap">
            <div class="fnmm-backend-container">
                <div class="fnmm-header">
                    <img src="<?php echo esc_url(FNMM_PLUGIN_URL . 'assets/images/fly-nav-mobile-logo.png'); ?>" alt="Fly Nav Mobile" class="fnmm-logo">
                </div>
                <div class="fnmm-vertical-layout">
                    <!-- Create tabs for different settings sections -->
                    <div class="fnmm-tabs">
                        <button class="fnmm-tab-link active" data-tab="general"><?php esc_html_e('General', 'fly-nav-mobile'); ?></button>
                        <button class="fnmm-tab-link" data-tab="appearance"><?php esc_html_e('Appearance', 'fly-nav-mobile'); ?></button>
                        <button class="fnmm-tab-link" data-tab="advanced"><?php esc_html_e('Advanced', 'fly-nav-mobile'); ?></button>
                    </div>
                    <!-- Create the settings form -->
                    <form action="options.php" method="post" class="fnmm-settings-form">
                        <?php
                        settings_fields('fnmm_options');
                        wp_nonce_field('fnmm_settings_action', 'fnmm_settings_nonce');
                        ?>
                        <!-- Tab content sections -->
                        <div class="fnmm-tab-content-container">
                            <!-- General settings section -->
                            <div id="fly-nav-mobile-general" class="fnmm-tab-content active">
                                <?php do_settings_sections('fly-nav-mobile-general'); ?>
                            </div>
                            <!-- Appearance settings section -->
                            <div id="fly-nav-mobile-appearance" class="fnmm-tab-content">
                                <?php do_settings_sections('fly-nav-mobile-appearance'); ?>
                            </div>
                            <!-- Advanced settings section -->
                            <div id="fly-nav-mobile-advanced" class="fnmm-tab-content">
                                <?php do_settings_sections('fly-nav-mobile-advanced'); ?>
                            </div>
                        </div>
                        <?php submit_button(esc_html__('Save Settings', 'fly-nav-mobile'), 'primary', 'submit', true, array('class' => 'button-primary')); ?>
                    </form>
                </div>
            </div>
        </div>
        <?php
    }

    // This function sets up all the settings fields and sections
    public function register_settings() {
        // Register the main settings
        register_setting('fnmm_options', 'fnmm_settings', array($this, 'sanitize_settings'));

        // Set up the General Settings section
        add_settings_section('fnmm_general_section', '', null, 'fly-nav-mobile-general');
        add_settings_field('fnmm_logo', esc_html__('Logo', 'fly-nav-mobile'), array($this, 'logo_callback'), 'fly-nav-mobile-general', 'fnmm_general_section');
        add_settings_field('fnmm_logo_width', esc_html__('Logo Width', 'fly-nav-mobile'), array($this, 'logo_width_callback'), 'fly-nav-mobile-general', 'fnmm_general_section');
        add_settings_field('fnmm_menu_select', esc_html__('Select Menu', 'fly-nav-mobile'), array($this, 'menu_select_callback'), 'fly-nav-mobile-general', 'fnmm_general_section');
        add_settings_field('fnmm_hide_current_header', esc_html__('Hide Current Header', 'fly-nav-mobile'), array($this, 'hide_current_header_callback'), 'fly-nav-mobile-general', 'fnmm_general_section');
        add_settings_field(
            'fnmm_search_icon',
            esc_html__('Search Icon', 'fly-nav-mobile'),
            array($this, 'search_icon_callback'),
            'fly-nav-mobile-general',
            'fnmm_general_section'
        );

        // Set up the Appearance Settings section
        add_settings_section('fnmm_appearance_section', '', null, 'fly-nav-mobile-appearance');
        add_settings_field('fnmm_header_bg_color', esc_html__('Header Background Color', 'fly-nav-mobile'), array($this, 'color_picker_callback'), 'fly-nav-mobile-appearance', 'fnmm_appearance_section', array('field' => 'header_bg_color'));
        add_settings_field('fnmm_dropdown_bg_color', esc_html__('Dropdown Menu Color', 'fly-nav-mobile'), array($this, 'color_picker_callback'), 'fly-nav-mobile-appearance', 'fnmm_appearance_section', array('field' => 'dropdown_bg_color'));
        add_settings_field('fnmm_menu_font', esc_html__('Menu Font', 'fly-nav-mobile'), array($this, 'font_select_callback'), 'fly-nav-mobile-appearance', 'fnmm_appearance_section');
        add_settings_field('fnmm_font_size', esc_html__('Font Size', 'fly-nav-mobile'), array($this, 'font_size_callback'), 'fly-nav-mobile-appearance', 'fnmm_appearance_section');

        // Add new setting for icon color
        add_settings_field(
            'fnmm_icon_color',
            esc_html__('Icon Color', 'fly-nav-mobile'),
            array($this, 'icon_color_callback'),
            'fly-nav-mobile-appearance',
            'fnmm_appearance_section'
        );

        // Register the icon color setting
        register_setting(
            'fnmm_options',
            'fnmm_settings',
            array(
                'type' => 'array',
                'sanitize_callback' => array($this, 'sanitize_settings'),
                'default' => array(
                    'icon_color' => '#333333',
                ),
            )
        );

        // Add new setting for menu font color
        add_settings_field(
            'fnmm_menu_font_color',
            esc_html__('Menu Font Color', 'fly-nav-mobile'),
            array($this, 'menu_font_color_callback'),
            'fly-nav-mobile-appearance',
            'fnmm_appearance_section'
        );

        // Set up the Advanced Settings section
        add_settings_section('fnmm_advanced_section', '', null, 'fly-nav-mobile-advanced');
        add_settings_field('fnmm_custom_css', esc_html__('Custom CSS', 'fly-nav-mobile'), array($this, 'custom_css_callback'), 'fly-nav-mobile-advanced', 'fnmm_advanced_section');

        // Register new setting for custom CSS
        register_setting(
            'fnmm_options',
            'fnmm_custom_css',
            array(
                'type' => 'string',
                'sanitize_callback' => 'wp_strip_all_tags',
                'default' => '',
            )
        );

        // Register new setting for menu font color
        register_setting(
            'fnmm_settings_group',
            'fnmm_menu_font_color',
            array(
                'type' => 'string',
                'sanitize_callback' => 'sanitize_hex_color',
                'default' => '#000000',
            )
        );

        // Register general options
        register_setting(
            'fnmm_options',
            'fnmm_options',
            array($this, 'sanitize_options')
        );
    }

    // This function loads the necessary scripts and styles for the settings page
    public function enqueue_scripts($hook) {
        if ($hook !== 'toplevel_page_fly-nav-mobile') {
            return;
        }
        wp_enqueue_style('wp-color-picker');
        wp_enqueue_style('fly-nav-mobile-backend', FNMM_PLUGIN_URL . 'backend/css/fly-nav-mobile-backend.css', array(), FNMM_VERSION);
        wp_enqueue_script('wp-color-picker');
        wp_enqueue_script('fly-nav-mobile-backend', FNMM_PLUGIN_URL . 'backend/js/fly-nav-mobile-backend.js', array('jquery', 'wp-color-picker'), FNMM_VERSION, true);
        wp_enqueue_media();
    }

    // The following functions create the HTML for each settings field

    // Logo upload field
    public function logo_callback() {
        $options = get_option('fnmm_settings');
        $logo_url = isset($options['logo_url']) ? $options['logo_url'] : '';
        ?>
        <div class="fnmm-logo-upload-wrapper">
            <input type="text" id="fnmm_logo_url" name="fnmm_settings[logo_url]" value="<?php echo esc_url($logo_url); ?>" class="regular-text">
            <input type="button" id="fnmm_upload_logo_button" class="button" value="<?php esc_attr_e('Upload Logo', 'fly-nav-mobile'); ?>">
        </div>
        <?php
    }

    // Logo width field
    public function logo_width_callback() {
        $options = get_option('fnmm_settings');
        $logo_width = isset($options['logo_width']) ? $options['logo_width'] : '100';
        ?>
        <input type="number" name="fnmm_settings[logo_width]" value="<?php echo esc_attr($logo_width); ?>" class="small-text"> px
        <?php
    }

    // Menu selection dropdown
    public function menu_select_callback() {
        $options = get_option('fnmm_settings');
        $selected_menu = isset($options['selected_menu']) ? $options['selected_menu'] : '';
        $menus = wp_get_nav_menus();
        ?>
        <select name="fnmm_settings[selected_menu]">
            <option value=""><?php esc_html_e('Select a menu', 'fly-nav-mobile'); ?></option>
            <?php foreach ($menus as $menu) : ?>
                <option value="<?php echo esc_attr($menu->term_id); ?>" <?php selected($selected_menu, $menu->term_id); ?>>
                    <?php echo esc_html($menu->name); ?>
                </option>
            <?php endforeach; ?>
        </select>
        <?php
    }

    // Color picker field
    public function color_picker_callback($args) {
        $options = get_option('fnmm_settings');
        $color = isset($options[$args['field']]) ? $options[$args['field']] : '#ffffff';
        ?>
        <input type="text" name="fnmm_settings[<?php echo esc_attr($args['field']); ?>]" value="<?php echo esc_attr($color); ?>" class="fnmm-color-picker">
        <?php
    }

    // Font selection dropdown
    public function font_select_callback() {
        $options = get_option('fnmm_settings');
        $selected_font = isset($options['menu_font']) ? $options['menu_font'] : 'Arial';
        $fonts = array('Arial', 'Helvetica', 'Georgia', 'Times New Roman', 'Courier');
        ?>
        <select name="fnmm_settings[menu_font]">
            <?php foreach ($fonts as $font) : ?>
                <option value="<?php echo esc_attr($font); ?>" <?php selected($selected_font, $font); ?>>
                    <?php echo esc_html($font); ?>
                </option>
            <?php endforeach; ?>
        </select>
        <?php
    }

    // Font size field
    public function font_size_callback() {
        $options = get_option('fnmm_settings');
        $font_size = isset($options['font_size']) ? $options['font_size'] : '16';
        ?>
        <input type="number" name="fnmm_settings[font_size]" value="<?php echo esc_attr($font_size); ?>" class="small-text"> px
        <?php
    }

    // Hide current header field
    public function hide_current_header_callback() {
        $options = get_option('fnmm_settings');
        $hide_header_class = isset($options['hide_header_class']) ? $options['hide_header_class'] : '';
        ?>
        <input type="text" name="fnmm_settings[hide_header_class]" value="<?php echo esc_attr($hide_header_class); ?>" class="regular-text">
        <p class="description">
            <?php 
            esc_html_e('Enter the CSS class or ID of your current header to hide it on mobile devices.', 'fly-nav-mobile'); 
            echo ' <a href="https://youtu.be/zBx--AESGpU?si=DXSDiC3HqvLSdl_b" target="_blank">' . esc_html__('Learn More', 'fly-nav-mobile') . '</a>';
            ?>
        </p>
        <?php
    }

    // Custom CSS field
    public function custom_css_callback() {
        $custom_css = get_option('fnmm_custom_css', '');
        ?>
        <textarea name="fnmm_custom_css" rows="10" cols="50" class="large-text code"><?php echo esc_textarea($custom_css); ?></textarea>
        <p class="description"><?php esc_html_e('Add custom CSS to further customize the mobile menu.', 'fly-nav-mobile'); ?></p>
        <?php
    }

    // Icon color field
    public function icon_color_callback() {
        $options = get_option('fnmm_settings');
        $icon_color = isset($options['icon_color']) ? $options['icon_color'] : '#333333';
        ?>
        <input type="text" name="fnmm_settings[icon_color]" value="<?php echo esc_attr($icon_color); ?>" class="fnmm-color-picker">
        <?php
    }

    // Menu font color field
    public function menu_font_color_callback() {
        $options = get_option('fnmm_settings');
        $menu_font_color = isset($options['menu_font_color']) ? $options['menu_font_color'] : '#000000';
        ?>
        <input type="text" name="fnmm_settings[menu_font_color]" value="<?php echo esc_attr($menu_font_color); ?>" class="fnmm-color-picker">
        <?php
    }

    // Search icon field
    public function search_icon_callback() {
        $options = get_option('fnmm_settings');
        $search_option = isset($options['search_icon']) ? $options['search_icon'] : 'show';
        ?>
        <select name="fnmm_settings[search_icon]" id="fnmm_search_icon">
            <option value="show" <?php selected($search_option, 'show'); ?>><?php esc_html_e('Show Search Icon', 'fly-nav-mobile'); ?></option>
            <option value="hide" <?php selected($search_option, 'hide'); ?>><?php esc_html_e('Hide Search Icon', 'fly-nav-mobile'); ?></option>
        </select>
        <?php
    }

    // This function cleans and validates the settings before saving
    public function sanitize_settings($input) {
        // Verify nonce and check permissions
        check_admin_referer('fnmm_settings_action', 'fnmm_settings_nonce');

        if (!current_user_can('manage_options')) {
            wp_die(esc_html__('You do not have sufficient permissions to access this page.', 'fly-nav-mobile'));
        }

        $sanitized_input = array();
        foreach ($input as $key => $value) {
            switch ($key) {
                case 'logo_url':
                    $sanitized_input[$key] = esc_url_raw($value);
                    break;
                case 'logo_width':
                case 'font_size':
                    $sanitized_input[$key] = absint($value);
                    break;
                case 'header_bg_color':
                case 'dropdown_bg_color':
                case 'icon_color':
                case 'menu_font_color':
                    $sanitized_input[$key] = sanitize_hex_color($value);
                    break;
                case 'menu_font':
                case 'hide_header_class':
                    $sanitized_input[$key] = sanitize_text_field($value);
                    break;
                case 'selected_menu':
                    $sanitized_input[$key] = absint($value);
                    break;
                case 'search_icon':
                    $sanitized_input[$key] = in_array($value, array('show', 'hide')) ? $value : 'show';
                    break;
            }
        }
        return $sanitized_input;
    }

    // This function cleans and validates the general options
    public function sanitize_options($input) {
        $sanitized_input = array();
        if (isset($input['fnmm_icon_color'])) {
            $sanitized_input['fnmm_icon_color'] = sanitize_hex_color($input['fnmm_icon_color']);
        }
        // Add sanitization for other options here
        return $sanitized_input;
    }

    // This function retrieves the plugin settings with default values
    public function get_plugin_settings() {
        $defaults = array(
            'fnmm_icon_color' => '#000000',
            // Add other default values here
        );
        $settings = get_option('fnmm_options', array());
        return wp_parse_args($settings, $defaults);
    }
}