<?php
// This class customizes how the mobile menu is built
class FNMM_Walker_Nav_Menu extends Walker_Nav_Menu {
    /**
     * This function builds each menu item.
     *
     * It's called for each item in the menu, and it creates the HTML for that item.
     */
    public function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0) {
        // Add some spacing to nested items
        $indent = ($depth) ? str_repeat("\t", $depth) : '';

        // Set up the CSS classes for this menu item
        $classes = empty($item->classes) ? array() : (array) $item->classes;
        $classes[] = 'menu-item-' . intval($item->ID);

        // Check if this item has sub-items (children)
        $has_children = in_array('menu-item-has-children', $classes);

        // Combine all the classes into a string
        $class_names = join(' ', apply_filters('nav_menu_css_class', array_filter($classes), $item, $args, $depth));
        $class_names = $class_names ? ' class="' . esc_attr($class_names) . '"' : '';

        // Create an ID for this menu item
        $id = apply_filters('nav_menu_item_id', 'menu-item-'. $item->ID, $item, $args, $depth);
        $id = $id ? ' id="' . esc_attr($id) . '"' : '';

        // Start building the HTML for this menu item
        $output .= $indent . '<li' . $id . $class_names . '>';

        // Set up the attributes for the link (like href, title, etc.)
        $atts = array();
        $atts['title']  = ! empty($item->attr_title) ? $item->attr_title : '';
        $atts['target'] = ! empty($item->target)     ? $item->target     : '';
        $atts['rel']    = ! empty($item->xfn)        ? $item->xfn        : '';
        $atts['href']   = ! empty($item->url)        ? $item->url        : '';

        // Allow other parts of WordPress to modify these attributes
        $atts = apply_filters('nav_menu_link_attributes', $atts, $item, $args, $depth);

        // Turn the attributes into a string
        $attributes = '';
        foreach ($atts as $attr => $value) {
            if (!empty($value)) {
                $value = ('href' === $attr) ? esc_url($value) : esc_attr($value);
                $attributes .= ' ' . $attr . '="' . $value . '"';
            }
        }

        // Build the HTML for the menu item
        $item_output = $args->before;
        $item_output .= '<a' . $attributes . '>';
        $item_output .= $args->link_before . esc_html(apply_filters('the_title', $item->title, $item->ID)) . $args->link_after;
        $item_output .= '</a>';

        if ($has_children && $depth === 0) {
            $item_output .= '<input type="checkbox" id="fnmm-submenu-' . esc_attr($item->ID) . '" class="fnmm-submenu-toggle">';
            $item_output .= '<label for="fnmm-submenu-' . esc_attr($item->ID) . '" class="fnmm-submenu-label"><div class="arrow-down-symbol"></div></label>';
        }

        $item_output .= $args->after;

        // Allow other parts of WordPress to modify the final output
        $output .= apply_filters('walker_nav_menu_start_el', $item_output, $item, $depth, $args);
    }

    /**
     * This function starts a new sub-menu.
     *
     * It's called when we need to start a new level in the menu (like for dropdowns).
     */
    public function start_lvl(&$output, $depth = 0, $args = array()) {
        $indent = str_repeat("\t", $depth);
        // Add a class to the sub-menu
        $class = apply_filters('fnmm_submenu_class', 'sub-menu');
        $output .= "\n$indent<ul class=\"" . esc_attr($class) . "\">\n";
    }
}