<?php
/**
 * Plugin Name: Fly Nav Mobile
 * Description: A lightweight mobile menu plugin for WordPress using only HTML and CSS.
 * Version: 1.1.3
 * Author: WPGeared
 * Author URI: https://wpgeared.com
 * License: GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: fly-nav-mobile
 * Domain Path: /languages
 * Tested up to: 6.7
 */

// Prevent direct access to this file
if (!defined('WPINC')) {
    die;
}

// Define plugin constants
define('FNMM_VERSION', '1.1.2');
define('FNMM_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('FNMM_PLUGIN_URL', plugin_dir_url(__FILE__));

// Include necessary files
require_once FNMM_PLUGIN_DIR . 'backend/class-fly-nav-mobile-backend.php';
require_once FNMM_PLUGIN_DIR . 'backend/class-fly-nav-mobile-walker.php'; // Include the custom walker
require_once FNMM_PLUGIN_DIR . 'public/class-fly-nav-mobile-public.php';

// Main function to run the plugin
if (!function_exists('fnmm_run_plugin')) {
    function fnmm_run_plugin() {
        // Create instances of backend and public classes
        $backend = new FNMM_Backend();
        $public = new FNMM_Public();

        // Backend hooks
        add_action('admin_menu', array($backend, 'add_settings_page'));
        add_action('admin_init', array($backend, 'register_settings'));
        add_action('admin_enqueue_scripts', array($backend, 'enqueue_scripts'));

        // Frontend hooks
        add_action('wp_enqueue_scripts', array($public, 'enqueue_styles'));
        add_action('wp_footer', array($public, 'render_mobile_menu'));

        // Hook for handling AJAX settings save
        add_action('wp_ajax_fnmm_save_settings', array($backend, 'handle_ajax_save_settings'));
    }
}
fnmm_run_plugin();

// Check if WordPress is at the required version
if (version_compare($GLOBALS['wp_version'], '5.0', '<')) {
    // Optionally deactivate the plugin
    deactivate_plugins(plugin_basename(__FILE__));
    wp_die(esc_html__('Fly Nav Mobile requires WordPress version 5.0 or higher.', 'fly-nav-mobile'));
}